/*
 * Copyright (c) 2009, GoodData Corporation. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of conditions and
 *        the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 *        and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *     * Neither the name of the GoodData Corporation nor the names of its contributors may be used to endorse
 *        or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.gooddata.config;

import java.util.ArrayList;
import java.util.List;

/**
 * Notification message
 *
 * @author zd@gooddata.com
 * @version 1.0
 */
public class NotificationMessage {

    private String condition;

    private List<Metric> metrics = new ArrayList<Metric>();
    private List<Report> reports = new ArrayList<Report>();

    private String message;

    private String uri;

    private String dupFilterExact;
    private String dupFilterKind;
    private String messageTimestampFormat;

    /**
     * Constructor
     *
     * @param condition the expression that uses the metric aliases. must resolve to boolean
     * @param metrics   metrics
     * @param message   the message (can use the %metric-alias% substitution fields)
     * @param uri       the target uri (e.g. mailto://zd@goodata.com)
     */
    public NotificationMessage(String condition, List<Metric> metrics, String message, String uri) {
        setCondition(condition);
        setMetrics(metrics);
        setMessage(message);
        setUri(uri);
    }

    public void addMetric(Metric m) {
        metrics.add(m);
    }

    public String getCondition() {
        return condition;
    }

    public void setCondition(String condition) {
        this.condition = condition;
    }

    public List<Metric> getMetrics() {
        return metrics;
    }

    public void setMetrics(List<Metric> metrics) {
        this.metrics = metrics;
    }

    public List<Report> getReports() {
        return reports;
    }

    public void setReports(List<Report> reports) {
        this.reports = reports;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getUri() {
        return uri;
    }

    public void setUri(String uri) {
        this.uri = uri;
    }

    public String getDupFilterExact() {
        return dupFilterExact;
    }

    public void setDupFilterExact(String dupFilterExact) {
        this.dupFilterExact = dupFilterExact;
    }

    public String getDupFilterKind() {
        return dupFilterKind;
    }

    public void setDupFilterKind(String dupFilterKind) {
        this.dupFilterKind = dupFilterKind;
    }

    public String getMessageTimestampFormat() {
        return messageTimestampFormat;
    }

    public void setMessageTimestampFormat(String messageTimestampFormat) {
        this.messageTimestampFormat = messageTimestampFormat;
    }
}
